@@ -9,7 +9,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.45'; # VERSION
+our $VERSION = '1.46'; # VERSION
 
 our %SPEC;
 
@@ -84,7 +84,7 @@ _
         },
         # XXX: flag to ignore references
     },
-    tags => [qw/format itemfunc/],
+    tags => [qw/datatype:bool itemfunc formatting/],
 };
 sub bool {
     my %args = @_;
@@ -131,7 +131,7 @@ Data::Unixish::bool - Format bool
 
 =head1 VERSION
 
-This document describes version 1.45 of Data::Unixish::bool (from Perl distribution Data-Unixish), released on 2014-05-02.
+This document describes version 1.46 of Data::Unixish::bool (from Perl distribution Data-Unixish), released on 2014-05-05.
 
 =head1 SYNOPSIS
 
