@@ -10,7 +10,7 @@ use warnings;
 use Data::Unixish::_pad;
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.45'; # VERSION
+our $VERSION = '1.46'; # VERSION
 
 our %SPEC;
 
@@ -57,7 +57,7 @@ _
             schema => ['bool', default => 0],
         },
     },
-    tags => [qw/format itemfunc/],
+    tags => [qw/itemfunc text/],
 };
 sub centerpad {
     my %args = @_;
@@ -82,7 +82,7 @@ Data::Unixish::centerpad - Center text to a certain column width
 
 =head1 VERSION
 
-This document describes version 1.45 of Data::Unixish::centerpad (from Perl distribution Data-Unixish), released on 2014-05-02.
+This document describes version 1.46 of Data::Unixish::centerpad (from Perl distribution Data-Unixish), released on 2014-05-05.
 
 =head1 SYNOPSIS
 
