@@ -12,7 +12,7 @@ use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 use Text::sprintfn ();
 
-our $VERSION = '1.45'; # VERSION
+our $VERSION = '1.46'; # VERSION
 
 our %SPEC;
 
@@ -42,7 +42,7 @@ _
             schema=>[bool => default=>0],
         },
     },
-    tags => [qw/format itemfunc/],
+    tags => [qw/formatting itemfunc text/],
 };
 sub sprintfn {
     my %args = @_;
@@ -118,7 +118,7 @@ Data::Unixish::sprintfn - Like sprintf, but use sprintfn() from Text::sprintfn
 
 =head1 VERSION
 
-This document describes version 1.45 of Data::Unixish::sprintfn (from Perl distribution Data-Unixish), released on 2014-05-02.
+This document describes version 1.46 of Data::Unixish::sprintfn (from Perl distribution Data-Unixish), released on 2014-05-05.
 
 =head1 SYNOPSIS
 
