@@ -9,7 +9,7 @@ use Scalar::Util 'looks_like_number';
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.45'; # VERSION
+our $VERSION = '1.46'; # VERSION
 
 our %SPEC;
 
@@ -19,7 +19,7 @@ $SPEC{sum} = {
     args => {
         %common_args,
     },
-    tags => [qw/group/],
+    tags => [qw/datatype:num group/],
 };
 sub sum {
     my %args = @_;
@@ -49,7 +49,7 @@ Data::Unixish::sum - Sum numbers
 
 =head1 VERSION
 
-This document describes version 1.45 of Data::Unixish::sum (from Perl distribution Data-Unixish), released on 2014-05-02.
+This document describes version 1.46 of Data::Unixish::sum (from Perl distribution Data-Unixish), released on 2014-05-05.
 
 =head1 SYNOPSIS
 
